@@ -44,7 +44,6 @@ struct _CcKeyboardItem
 
   CcKeyCombo *primary_combo;
   BindingGroupType group;
-  GtkTreeModel *model;
   char *description;
   gboolean editable;
   GList *key_combos;
@@ -609,9 +608,8 @@ settings_get_binding (GSettings  *settings,
 }
 
 static void
-binding_changed (GSettings *settings,
-		 const char *key,
-		 CcKeyboardItem *item)
+binding_changed (CcKeyboardItem *item,
+		 const char *key)
 {
   char *value;
 
@@ -656,8 +654,8 @@ cc_keyboard_item_load_from_gsettings_path (CcKeyboardItem *item,
   g_free (item->binding);
   item->binding = settings_get_binding (item->settings, item->key);
   binding_from_string (item->binding, item->primary_combo);
-  g_signal_connect (G_OBJECT (item->settings), "changed::binding",
-		    G_CALLBACK (binding_changed), item);
+  g_signal_connect_object (G_OBJECT (item->settings), "changed::binding",
+                           G_CALLBACK (binding_changed), item, G_CONNECT_SWAPPED);
 
   return TRUE;
 }
@@ -687,8 +685,8 @@ cc_keyboard_item_load_from_gsettings (CcKeyboardItem *item,
   item->default_combos = settings_get_key_combos (item->settings, item->key, TRUE);
 
   signal_name = g_strdup_printf ("changed::%s", item->key);
-  g_signal_connect (G_OBJECT (item->settings), signal_name,
-		    G_CALLBACK (binding_changed), item);
+  g_signal_connect_object (G_OBJECT (item->settings), signal_name,
+                           G_CALLBACK (binding_changed), item, G_CONNECT_SWAPPED);
   g_free (signal_name);
 
   return TRUE;
@@ -860,14 +858,6 @@ cc_keyboard_item_get_item_type (CcKeyboardItem *item)
   return item->type;
 }
 
-void
-cc_keyboard_item_set_model (CcKeyboardItem *item, GtkTreeModel *model, BindingGroupType group)
-{
-  g_return_if_fail (CC_IS_KEYBOARD_ITEM (item));
-  item->model = model;
-  item->group = group;
-}
-
 const gchar *
 cc_keyboard_item_get_gsettings_path (CcKeyboardItem *item)
 {
